import 'package:flutter/foundation.dart';

/// Model class for iOS callbacks.
///
/// Callbacks (pointers) are called in talsec_config.
class IOScallback {
  /// Callback called when app signature does not match expected one
  final VoidCallback? onSignatureDetected;

  /// Callback called when jailbreak on device is detected
  final VoidCallback? onJailbreakDetected;

  /// Callback called when app is manipulated on runtime
  final VoidCallback? onRuntimeManipulationDetected;

  /// Callback called when device is not protected by passcode
  final VoidCallback? onPasscodeDetected;

  /// Callback called when passcode protection of device was changed or removed
  final VoidCallback? onPasscodeChangeDetected;

  /// Callback called when app is running on simulator
  final VoidCallback? onSimulatorDetected;

  /// Callback called when secure enclave layer is missing
  final VoidCallback? onMissingSecureEnclaveDetected;

  /// Callback called when device was changed
  final VoidCallback? onDeviceChangeDetected;

  /// Callback called when device ID detected
  final VoidCallback? onDeviceIdDetected;

  IOScallback({
    this.onSignatureDetected,
    this.onJailbreakDetected,
    this.onRuntimeManipulationDetected,
    this.onPasscodeDetected,
    this.onPasscodeChangeDetected,
    this.onSimulatorDetected,
    this.onMissingSecureEnclaveDetected,
    this.onDeviceChangeDetected,
    this.onDeviceIdDetected,
  });
}
